==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpScaleRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpScaleRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Container App container Http scaling rule.
 * @property auth Authentication secrets for the custom scale rule.
 * @property metadata Metadata properties to describe http scale rule.
 */
public data class HttpScaleRuleArgs(
    public val auth: Output<List<ScaleRuleAuthArgs>>? = null,
    public val metadata: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpScaleRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpScaleRuleArgs =
        com.pulumi.azurenative.app.inputs.HttpScaleRuleArgs.builder()
            .auth(auth?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .metadata(
                metadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [HttpScaleRuleArgs].
 */
@PulumiTagMarker
public class HttpScaleRuleArgsBuilder internal constructor() {
    private var auth: Output<List<ScaleRuleAuthArgs>>? = null

    private var metadata: Output<Map<String, String>>? = null

    /**
     * @param value Authentication secrets for the custom scale rule.
     */
    @JvmName("dhnxwmijgkelyshw")
    public suspend fun auth(`value`: Output<List<ScaleRuleAuthArgs>>) {
        this.auth = value
    }

    @JvmName("aajunukgxjeenmfi")
    public suspend fun auth(vararg values: Output<ScaleRuleAuthArgs>) {
        this.auth = Output.all(values.asList())
    }

    /**
     * @param values Authentication secrets for the custom scale rule.
     */
    @JvmName("pkqsgkidoahilhld")
    public suspend fun auth(values: List<Output<ScaleRuleAuthArgs>>) {
        this.auth = Output.all(values)
    }

    /**
     * @param value Metadata properties to describe http scale rule.
     */
    @JvmName("cdbhyxigxgysfkiv")
    public suspend fun metadata(`value`: Output<Map<String, String>>) {
        this.metadata = value
    }

    /**
     * @param value Authentication secrets for the custom scale rule.
     */
    @JvmName("kdewruvjmcwvdkjv")
    public suspend fun auth(`value`: List<ScaleRuleAuthArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("uxjjwsrfwmkrghka")
    public suspend fun auth(argument: List<suspend ScaleRuleAuthArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ScaleRuleAuthArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("uaorafjuamiajqeh")
    public suspend fun auth(vararg argument: suspend ScaleRuleAuthArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ScaleRuleAuthArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("wsdcwttqemgpolyb")
    public suspend fun auth(argument: suspend ScaleRuleAuthArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleRuleAuthArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param values Authentication secrets for the custom scale rule.
     */
    @JvmName("txcjmenjjacegigd")
    public suspend fun auth(vararg values: ScaleRuleAuthArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.auth = mapped
    }

    /**
     * @param value Metadata properties to describe http scale rule.
     */
    @JvmName("umswgaelceaoojwl")
    public suspend fun metadata(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param values Metadata properties to describe http scale rule.
     */
    @JvmName("aiuwfdhimikgmynr")
    public fun metadata(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    internal fun build(): HttpScaleRuleArgs = HttpScaleRuleArgs(
        auth = auth,
        metadata = metadata,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpScaleRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpScaleRuleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Container App container Http scaling rule.
 * @property auth Authentication secrets for the custom scale rule.
 * @property metadata Metadata properties to describe http scale rule.
 */
public data class HttpScaleRuleArgs(
    public val auth: Output<List<ScaleRuleAuthArgs>>? = null,
    public val metadata: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpScaleRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpScaleRuleArgs =
        com.pulumi.azurenative.app.inputs.HttpScaleRuleArgs.builder()
            .auth(auth?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .metadata(
                metadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [HttpScaleRuleArgs].
 */
@PulumiTagMarker
public class HttpScaleRuleArgsBuilder internal constructor() {
    private var auth: Output<List<ScaleRuleAuthArgs>>? = null

    private var metadata: Output<Map<String, String>>? = null

    /**
     * @param value Authentication secrets for the custom scale rule.
     */
    @JvmName("aymwvahbavdnrlow")
    public suspend fun auth(`value`: Output<List<ScaleRuleAuthArgs>>) {
        this.auth = value
    }

    @JvmName("hhvqanydktuuyuhw")
    public suspend fun auth(vararg values: Output<ScaleRuleAuthArgs>) {
        this.auth = Output.all(values.asList())
    }

    /**
     * @param values Authentication secrets for the custom scale rule.
     */
    @JvmName("xpskeyhdqjrjayny")
    public suspend fun auth(values: List<Output<ScaleRuleAuthArgs>>) {
        this.auth = Output.all(values)
    }

    /**
     * @param value Metadata properties to describe http scale rule.
     */
    @JvmName("ohaollysseclppij")
    public suspend fun metadata(`value`: Output<Map<String, String>>) {
        this.metadata = value
    }

    /**
     * @param value Authentication secrets for the custom scale rule.
     */
    @JvmName("brhfetqxoaqawhem")
    public suspend fun auth(`value`: List<ScaleRuleAuthArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("epqdltodakrrydad")
    public suspend fun auth(argument: List<suspend ScaleRuleAuthArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ScaleRuleAuthArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("bqkotnthxxlxirfy")
    public suspend fun auth(vararg argument: suspend ScaleRuleAuthArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ScaleRuleAuthArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param argument Authentication secrets for the custom scale rule.
     */
    @JvmName("qiurcqmbmqnsrwrw")
    public suspend fun auth(argument: suspend ScaleRuleAuthArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleRuleAuthArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.auth = mapped
    }

    /**
     * @param values Authentication secrets for the custom scale rule.
     */
    @JvmName("qdjbfauyjtvhipah")
    public suspend fun auth(vararg values: ScaleRuleAuthArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.auth = mapped
    }

    /**
     * @param value Metadata properties to describe http scale rule.
     */
    @JvmName("gokuqhxfpmckckue")
    public suspend fun metadata(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    /**
     * @param values Metadata properties to describe http scale rule.
     */
    @JvmName("vbqqqxghrtuhouqq")
    public fun metadata(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    internal fun build(): HttpScaleRuleArgs = HttpScaleRuleArgs(
        auth = auth,
        metadata = metadata,
    )
}
